pub struct TypedWebhook<T>(pub T);Expand description
Axum extractor that verifies the webhooksmith signature and deserializes the
JSON body into T.
Returns 422 if the body doesn’t match T.
Tuple Fields
0: TTrait Implementations
Sourceimpl<S, T> FromRequest<S> for TypedWebhook<T>
impl<S, T> FromRequest<S> for TypedWebhook<T>
Sourcetype Rejection = WebhookRejection
type Rejection = WebhookRejection
If the extractor fails it’ll use this “rejection” type. A rejection is
a kind of error that can be converted into a response.